# SharpTools

SharpTools je jednoduchý Python balíček, který obsahuje několik užitečných funkcí pro práci s čísly a textem.

## 📥 Instalace

Stačí použít `pip`:


## 🚀 Použití

```python
import sharptools

print(sharptools.nahodne_cislo())  # Náhodné číslo (např. 42)
print(sharptools.secti(10, 20))  # 30
print(sharptools.veliky_text("ahoj"))  # AHOJ
print(sharptools.maly_text("ČAU"))  # čau
print(sharptools.text_to_emoji(text)) #Převede text na emoji
print(sharptools.generate_password(length))
